// This is a SOAP client example for JS object in EasyBuilder Pro
// This example uses fast-xml-parser v4.0.4 from https://github.com/NaturalIntelligence/fast-xml-parser
// Learn how to use it at https://github.com/NaturalIntelligence/fast-xml-parser/blob/master/docs/v4/1.GettingStarted.md
const request = require('./request-0.0.2.js');
const fxp = require('./js-demo-soap-fxp-v4.0.4.min.js');

var number = Math.round(Math.random() * 1000);

console.log("number:", number);

// soap input data
var xmlData = `<?xml version="1.0" encoding="utf-8"?>
<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
    <soap:Body>
    <NumberToWords xmlns="http://www.dataaccess.com/webservicesserver/">
        <ubiNum>${number}</ubiNum>
    </NumberToWords>
    </soap:Body>
</soap:Envelope>`;

// validate before sending
var validateResult = fxp.XMLValidator.validate(xmlData);
if (validateResult.err != undefined) {
    console.error("error while parsing xml data: ", validateResult.err);
}

// ---- this block is an example and can be commented out
// quick example of parsing and building with fast-xml-parser
function testFxpParserAndBuilder() {
    const parser = new fxp.XMLParser();
    let jsonObj = parser.parse(xmlData);

    const builder = new fxp.XMLBuilder();
    let samleXmlData = builder.build(jsonObj);

    console.log("testFxpParserAndBuilder:", jsonObj, samleXmlData);
}
testFxpParserAndBuilder();
// ---- this block is an example

// Send the get request
request.post(
    {
        url: 'https://www.dataaccess.com/webservicesserver/numberconversion.wso',
        data: xmlData,
        header: {
            "content-type": "text/xml; charset=utf-8",
        }
    },
    function (error, response, body) {
        if (error !== "No error") {
            console.error(error);
            console.error("response: ", response);
            console.error("body: ", body);
        } else {
            console.log("status code: ", response.statusCode);
            const parser = new fxp.XMLParser();
            let jsonObj = parser.parse(body);
            console.log("jsonObj: ", jsonObj);
            console.log("answer:", jsonObj["soap:Envelope"]["soap:Body"]["m:NumberToWordsResponse"]["m:NumberToWordsResult"]);
        }
    }
);